==> dnet-openaireplus-workflows-2.2.0-20141222.094449-7-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/stats/PromoteShadowStatsJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.stats;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.tools.blackboard.BlackboardJob;

/**
 * Ask the StatsManagerService to promote the shadow stats db and cache to public for the portal specified by the additional BB parameter
 * <code>StatsManagerServiceBBAction.PROMOTE_SHADOW_STATS.getPortalParamName()</code>.
 * 
 * <p>
 * According to the StatsManagerService specifications in https://issue.openaire.research-infrastructures.eu/issues/914#note-49, this BB
 * action will:
 * <ol>
 * <li>promote the shadow cache to public</li>
 * <li>make a backup of the current stats db schema under the name 'backup'</li>
 * <li>replace it with the new one</li>
 * </ol>
 * </p>
 * 
 * @author alessia
 * 
 */
public class PromoteShadowStatsJobNode extends AbstractStatsJobNode {

	private static final Log log = LogFactory.getLog(PromoteShadowStatsJobNode.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Override
	protected void prepareJob(final BlackboardJob job, final NodeToken token) throws Exception {
		job.setAction(StatsManagerServiceBBAction.PROMOTE_SHADOW_STATS.action());
		String portal = getTargetPortal(token);
		if (StringUtils.isNotBlank(portal)) {
			job.getParameters().put(StatsManagerServiceBBAction.PROMOTE_SHADOW_STATS.getPortalParamName(), portal);
		} else {
			log.warn(StatsManagerServiceBBAction.PROMOTE_SHADOW_STATS.getPortalParamName() + " not set. The StatsManagerService will use its default.");
		}
	}

}

==> dnet-openaireplus-workflows-5.3.7-20160620.140843-6-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/stats/PromoteShadowStatsJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.stats;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.tools.blackboard.BlackboardJob;

/**
 * Ask the StatsManagerService to promote the shadow stats db and cache to public for the portal specified by the additional BB parameter
 * <code>StatsManagerServiceBBAction.PROMOTE_SHADOW_STATS.getTargetPortalParamName()</code>.
 * 
 * <p>
 * According to the StatsManagerService specifications in https://issue.openaire.research-infrastructures.eu/issues/914#note-49, this BB
 * action will:
 * <ol>
 * <li>promote the shadow cache to public</li>
 * <li>make a backup of the current stats db schema under the name 'backup'</li>
 * <li>replace it with the new one</li>
 * </ol>
 * </p>
 * 
 * @author alessia
 * 
 */
public class PromoteShadowStatsJobNode extends AbstractStatsJobNode {

	private static final Log log = LogFactory.getLog(PromoteShadowStatsJobNode.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Override
	protected void prepareJob(final BlackboardJob job, final NodeToken token) throws Exception {
		job.setAction(StatsManagerServiceBBAction.PROMOTE_SHADOW_STATS.action());
		String portal = getPortalName(token);
		if (StringUtils.isNotBlank(portal)) {
			job.getParameters().put(StatsManagerServiceBBAction.PROMOTE_SHADOW_STATS.getTargetPortalParamName(), portal);
		} else {
			log.warn(StatsManagerServiceBBAction.PROMOTE_SHADOW_STATS.getTargetPortalParamName() + " not set. The StatsManagerService will use its default.");
		}
	}

}
